From khali@linux-fr.org Mon May 16 09:55:51 2005
Date: Mon, 16 May 2005 18:52:38 +0200
From: Jean Delvare <khali@linux-fr.org>
To: Greg KH <greg@kroah.com>
Subject: I2C: Kill common macro abuse in chip drivers
Message-Id: <20050516185238.1dd20356.khali@linux-fr.org>

This patch kills a common macro abuse in i2c chip drivers: defining
ALARMS_FROM_REG returning its argument unchanged. Dropping the macro
makes the code somewhat more readable IMHO.

Signed-off-by: Jean Delvare <khali@linux-fr.org>
Signed-off-by: Greg Kroah-Hartman <gregkh@suse.de>

---
 drivers/i2c/chips/asb100.c  |    4 +---
 drivers/i2c/chips/it87.c    |    4 +---
 drivers/i2c/chips/lm85.c    |    4 +---
 drivers/i2c/chips/via686a.c |    4 +---
 drivers/i2c/chips/w83781d.c |    3 +--
 5 files changed, 5 insertions(+), 14 deletions(-)

--- gregkh-2.6.orig/drivers/i2c/chips/asb100.c	2005-05-17 23:40:26.000000000 -0700
+++ gregkh-2.6/drivers/i2c/chips/asb100.c	2005-05-17 23:40:27.000000000 -0700
@@ -169,8 +169,6 @@
 	return reg * 16;
 }
 
-#define ALARMS_FROM_REG(val) (val)
-
 #define DIV_FROM_REG(val) (1 << (val))
 
 /* FAN DIV: 1, 2, 4, or 8 (defaults to 2)
@@ -557,7 +555,7 @@
 static ssize_t show_alarms(struct device *dev, struct device_attribute *attr, char *buf)
 {
 	struct asb100_data *data = asb100_update_device(dev);
-	return sprintf(buf, "%d\n", ALARMS_FROM_REG(data->alarms));
+	return sprintf(buf, "%u\n", data->alarms);
 }
 
 static DEVICE_ATTR(alarms, S_IRUGO, show_alarms, NULL);
--- gregkh-2.6.orig/drivers/i2c/chips/it87.c	2005-05-17 23:40:14.000000000 -0700
+++ gregkh-2.6/drivers/i2c/chips/it87.c	2005-05-17 23:40:27.000000000 -0700
@@ -172,8 +172,6 @@
 					((val)+500)/1000),-128,127))
 #define TEMP_FROM_REG(val) (((val)>0x80?(val)-0x100:(val))*1000)
 
-#define ALARMS_FROM_REG(val) (val)
-
 #define PWM_TO_REG(val)   ((val) >> 1)
 #define PWM_FROM_REG(val) (((val)&0x7f) << 1)
 
@@ -665,7 +663,7 @@
 static ssize_t show_alarms(struct device *dev, struct device_attribute *attr, char *buf)
 {
 	struct it87_data *data = it87_update_device(dev);
-	return sprintf(buf,"%d\n", ALARMS_FROM_REG(data->alarms));
+	return sprintf(buf, "%u\n", data->alarms);
 }
 static DEVICE_ATTR(alarms, S_IRUGO, show_alarms, NULL);
 
--- gregkh-2.6.orig/drivers/i2c/chips/lm85.c	2005-05-17 23:40:14.000000000 -0700
+++ gregkh-2.6/drivers/i2c/chips/lm85.c	2005-05-17 23:40:27.000000000 -0700
@@ -284,8 +284,6 @@
 /* i2c-vid.h defines vid_from_reg() */
 #define VID_FROM_REG(val,vrm) (vid_from_reg((val),(vrm)))
 
-#define ALARMS_FROM_REG(val) (val)
-
 /* Unlike some other drivers we DO NOT set initial limits.  Use
  * the config file to set limits.  Some users have reported
  * motherboards shutting down when we set limits in a previous
@@ -480,7 +478,7 @@
 static ssize_t show_alarms_reg(struct device *dev, struct device_attribute *attr, char *buf)
 {
 	struct lm85_data *data = lm85_update_device(dev);
-	return sprintf(buf, "%ld\n", (long) ALARMS_FROM_REG(data->alarms));
+	return sprintf(buf, "%u\n", data->alarms);
 }
 
 static DEVICE_ATTR(alarms, S_IRUGO, show_alarms_reg, NULL);
--- gregkh-2.6.orig/drivers/i2c/chips/via686a.c	2005-05-17 23:40:14.000000000 -0700
+++ gregkh-2.6/drivers/i2c/chips/via686a.c	2005-05-17 23:40:27.000000000 -0700
@@ -292,8 +292,6 @@
 	        tempLUT[eightBits + 1] * twoBits) * 25;
 }
 
-#define ALARMS_FROM_REG(val) (val)
-
 #define DIV_FROM_REG(val) (1 << (val))
 #define DIV_TO_REG(val) ((val)==8?3:(val)==4?2:(val)==1?0:1)
 
@@ -570,7 +568,7 @@
 /* Alarms */
 static ssize_t show_alarms(struct device *dev, struct device_attribute *attr, char *buf) {
 	struct via686a_data *data = via686a_update_device(dev);
-	return sprintf(buf,"%d\n", ALARMS_FROM_REG(data->alarms));
+	return sprintf(buf, "%u\n", data->alarms);
 }
 static DEVICE_ATTR(alarms, S_IRUGO, show_alarms, NULL);
 
--- gregkh-2.6.orig/drivers/i2c/chips/w83781d.c	2005-05-17 23:40:14.000000000 -0700
+++ gregkh-2.6/drivers/i2c/chips/w83781d.c	2005-05-17 23:40:27.000000000 -0700
@@ -172,7 +172,6 @@
 						: (val)) / 1000, 0, 0xff))
 #define TEMP_FROM_REG(val)		(((val) & 0x80 ? (val)-0x100 : (val)) * 1000)
 
-#define ALARMS_FROM_REG(val)		(val)
 #define PWM_FROM_REG(val)		(val)
 #define PWM_TO_REG(val)			(SENSORS_LIMIT((val),0,255))
 #define BEEP_MASK_FROM_REG(val,type)	((type) == as99127f ? \
@@ -523,7 +522,7 @@
 show_alarms_reg(struct device *dev, struct device_attribute *attr, char *buf)
 {
 	struct w83781d_data *data = w83781d_update_device(dev);
-	return sprintf(buf, "%ld\n", (long) ALARMS_FROM_REG(data->alarms));
+	return sprintf(buf, "%u\n", data->alarms);
 }
 
 static
